package com.hyperling.roomexample

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.activity.viewModels
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import androidx.room.Room
import com.hyperling.roomexample.ui.theme.ExampleRoomDatabase21EmptyTheme

class MainActivity : ComponentActivity() {

    private val _db by lazy {
        Room.databaseBuilder(
            applicationContext,
            ContactDatabase::class.java,
            "contacts.db"
        ).build()
    }
    private val _viewModel by viewModels<ContactViewModel> (
        factoryProducer = {
            object : ViewModelProvider.Factory {
                override fun <T : ViewModel> create(modelClass: Class<T>): T {
                    return ContactViewModel(_db.dao) as T
                }
            }
        }
    )

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            ExampleRoomDatabase21EmptyTheme {
                val state by _viewModel.state.collectAsState()
                ContactScreen(
                    state = state,
                    onEvent = _viewModel::onEvent
                )
            }
        }
    }
}

/* * /
@Preview(showBackground = true)
@Composable
fun GreetingPreview() {
    ExampleRoomDatabase21EmptyTheme {
        ContactScreen (

        )
    }
}
// */